@@ -98,7 +98,7 @@ def print_list(func):
 class SensiML(object):
     """Entrance to SensiML Analytics Toolkit"""
 
-    # Server Minimum Version For Campatibility
+    # Server Minimum Version For Compatibility
     __minversion__ = "2019.1.0"
 
     def __init__(
@@ -422,8 +422,8 @@ class SensiML(object):
         return self._project._sandboxes.build_sandbox_list()
 
     @print_list
-    def list_pielines(self, get_objects=False):
-        """List all piplines for the active project.
+    def list_pipelines(self, get_objects=False):
+        """List all pipelines for the active project.
 
         Args:
             get_objects (bool, False): Also return the sandbox objects.
@@ -492,9 +492,7 @@ class SensiML(object):
 
         new = False
         if query is not None and not force:
-            raise QueryExistsException(
-                "Query already exists. Set force=True to overwrite."
-            )
+            raise Exception("Query already exists. Set force=True to overwrite.")
         elif query is not None and force:
             query.columns.clear()
             query.metadata_columns.clear()
@@ -529,12 +527,15 @@ class SensiML(object):
         if capture_configurations:
             query.capture_configurations = capture_configurations
 
+        query.metadata_columns.add("segment_uuid")
+
         if isinstance(segmenter, str):
             segmenters = self.list_segmenters()
             segmenter_id = segmenters[segmenters["name"] == segmenter].id
             if segmenter_id.shape[0] != 1:
                 raise Exception("Segmenter {} not found".format(segmenter))
-            query.segmenter = int(segmenter_id[0])
+
+            query.segmenter = int(segmenter_id.values[0])
         else:
             query.segmenter = segmenter
 
@@ -566,7 +567,9 @@ class SensiML(object):
         else:
             new = False
             if not force:
-                raise FeatureFileExistsException()
+                raise Exception(
+                    "A file with this name already exists. Use force=True to override"
+                )
 
         feature_file.filename = name
         feature_file.is_features = is_features
