@@ -47,9 +47,9 @@ class ConnectionConfig(dict):
                 pass
 
         if path:
-            config.readfp(open(path))
+            config.read_file(open(path))
         elif stream:
-            config.readfp(io.BytesIO(stream))
+            config.read_file(io.BytesIO(stream))
 
         self.path = path
         self.update({t[0]: t[1] for t in config.items(self.server)})
@@ -117,8 +117,7 @@ class ConnectionConfig(dict):
         return self
 
     def create_config_object(self, path=None, url=None, auth_url=None):
-        """Creates new config section if needed
-        """
+        """Creates new config section if needed"""
         path = path if path else self.path
 
         self.url = url
