@@ -70,7 +70,11 @@ class Functions:
         Returns:
             function
         """
-        return self.function_list.get(name, None)
+        func = self.function_list.get(name, None)
+        if func is None:
+            raise Exception("No function named {name}".format(name=name))
+
+        return func
 
     def _new_function_from_dict(self, dict):
         """Creates and populates a function from a set of properties.
