@@ -11,6 +11,8 @@ import matplotlib.pyplot as plt
 from typing import List, Optional, Dict, Tuple
 import wave
 
+from sensiml.dclproj.utils import plot_segments_labels, mfcc
+
 
 class DCLProject:
     def __init__(self):
@@ -49,7 +51,7 @@ class DCLProject:
         """create a database connection to the SQLite database
             specified by db_file
         :param db_file: database file
-        :return: Connection object or None
+        :return: None
         """
         self._path = os.path.dirname(db_file)
         if not os.path.exists(db_file):
@@ -199,7 +201,14 @@ class DCLProject:
         return DataFrame(M).fillna("")
 
     def list_captures(self, include_metadata: bool = True) -> DataFrame:
-        "returns a dataframe containing the capture information. If inlcude_metadta is True, also returns the associated metadata information with each capture."
+        """List the captures in the DCLI project file
+
+        Args:
+            include_metadata (bool, optional): If True return the associated metadata information with each capture. Defaults to True.
+
+        Returns:
+            DataFrame: DataFrame containing the capture information
+        """ ""
 
         fields = [
             "uuid",
@@ -242,6 +251,15 @@ class DCLProject:
     def list_capture_segments(
         self, captures: Optional[List] = None, sessions: Optional[List] = None
     ) -> DataFrame:
+        """Returns a DataFrame of segment information that are in the captures and sessions specified
+
+        Args:
+            captures (Optional[List], optional): A list of captures to return segments about. Defaults to None.
+            sessions (Optional[List], optional): A list of sessions to return segments for. Defaults to None.
+
+        Returns:
+            DataFrame: _description_
+        """
 
         if captures is not None and isinstance(captures, str):
             captures = [captures]
@@ -289,7 +307,14 @@ class DCLProject:
         )
 
     def get_capture_metadata(self, capture: str) -> DataFrame:
-        "returns a dataframe containing the metadata associated with this capture"
+        """Gets the metadata for the specified capture
+
+        Args:
+            capture (str): name of the capture file
+
+        Returns:
+            DataFrame: DataFrame containing the metadata associated with this capture
+        """
 
         fields = ["uuid"]
 
@@ -311,9 +336,6 @@ class DCLProject:
         Args:
             capture_name (str): name of capture
             session (str):  name of session where the labels are
-            recognized (Dataframe): results from recognize signal on this capture
-            class_map (dict): The class map describing how to map the labels to integer values
-            groups (dict): a dict of key value pairs where the key is the original label the value is the label it was should be renamed to
 
         """
         if captures is not None and isinstance(captures, str):
@@ -521,6 +543,51 @@ class DCLProject:
 
         return capture.reset_index(drop=True)
 
+    def plot_frequency(
+        self,
+        capture_name: str,
+        channel: str,
+        sample_freq: int = 16000,
+        figsize: Tuple = (30, 4),
+        session: Optional[str] = None,
+    ):
+
+        nrows = 3
+        data = self.get_capture(capture_name)
+
+        fig, axes = plt.subplots(
+            nrows=nrows, ncols=1, figsize=(figsize[0], figsize[1] * nrows)
+        )
+        fig.tight_layout()
+
+        data.plot(ax=axes[0], title=capture_name, xlim=(0, data.shape[0]), xlabel="")
+
+        _ = axes[1].specgram(data[channel], NFFT=512)
+        axes[1].set_title("Sepctrogram")
+
+        axes[2].imshow(
+            mfcc(data, channel, sample_freq=sample_freq, plot_all=False), aspect="auto"
+        )
+        axes[2].set_title("MFCC")
+
+        if session:
+            segments = self.list_capture_segments(
+                captures=[capture_name], sessions=[session]
+            )
+
+            plot_segments_labels(
+                segments,
+                axes=axes[0],
+                y_label=(
+                    data[channel].min(),
+                    int(data[channel].max()) - int(data[channel].min()),
+                ),
+            )
+
+        plt.subplots_adjust(hspace=0.2)
+
+        return axes
+
 
 def plot_segments_on_capture(
     capture,
