@@ -46,7 +46,7 @@ class DeviceFlasher(object):
             print(sub_proc.stderr.read().decode("UTF-8"))
             p_val = sub_proc.poll()
 
-        if p_val is 0:
+        if p_val == 0:
             print("Process Completed successfully.")
         else:
             print("And error occured. Error code {}".format(p_val))
