@@ -779,7 +779,9 @@ class Pipeline(object):
         """
 
         query_call = self._kb.functions.create_query_call(name)
-        query_call.query = self._project.queries.get_query_by_name(name)
+        query_call.query = self._project.queries.get_query_by_name(
+            name, raise_exception=True
+        )
         query_call.use_session_preprocessor = use_session_preprocessor
 
         self._dataset = query_call
